Welcome to ClientVPS Mirrors

Help for package CTTShiny
Type: Package
Title: Classical Test Theory via Shiny
Version: 0.1
Date: 2015-08-05
Maintainer: William Kyle Hamilton <kyle.hamilton@gmail.com>
Description: Interactive shiny application for running classical test theory (item analysis).
License: GPL-3
Depends: R (≥ 3.0.3)
Imports: shiny, shinyAce, CTT, ltm, psych
NeedsCompilation: no
Packaged: 2015-08-06 02:44:36 UTC; Lab Coordinator
Author: William Kyle Hamilton [aut, cre], Atsushi Mizumoto [aut]
Repository: CRAN
Date/Publication: 2015-08-06 07:15:41

This function will start CTTShiny

Description

An interactive Shiny application for running CTT analysis.

Usage

startCTT()

Details

Start CTTShiny

This starts the Shiny application CTT

Value

Nothing

Examples

## Not run: 
library(shiny)
startCTT()

## End(Not run)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.